NOMES_CONTAINERS_PADRAO = {
    "enterprise": "enterprise",
    "enterprise_event_handler": "enterprise-event-handler",
    "enterprise_renderizador": "enterprise-renderizador",
    "api_gateway": "api-gateway",
    "api_gateway_mtls_proxy": "mtls-proxy",
    "microkafka": "microkafka",
    "microkafka_zookeeper": "zookeeper",
    "microkafka_configurador": "configurar-microkafka",
    "microkafka_ui": "microkafka-ui",
    "mu_whatsapp": "muwhatsapp",
    "proxy_https_linux": "proxy-apienterprise",
}


def obter_nome_container_enterprise(configuracoes):
    return NOMES_CONTAINERS_PADRAO["enterprise"]


def obter_nome_container_enterprise_event_handler(configuracoes):
    return NOMES_CONTAINERS_PADRAO["enterprise_event_handler"]


def obter_nome_container_enterprise_renderizador(configuracoes):
    return NOMES_CONTAINERS_PADRAO["enterprise_renderizador"]


def obter_nome_container_api_gateway(configuracoes):
    return NOMES_CONTAINERS_PADRAO["api_gateway"]


def obter_nome_container_api_gateway_mtls_proxy(configuracoes):
    return NOMES_CONTAINERS_PADRAO["api_gateway_mtls_proxy"]


def obter_nome_container_microkafka(configuracoes):
    return NOMES_CONTAINERS_PADRAO["microkafka"]


def obter_nome_container_zookeeper(configuracoes):
    return NOMES_CONTAINERS_PADRAO["microkafka_zookeeper"]


def obter_nome_container_configurar_microkafka(configuracoes):
    return NOMES_CONTAINERS_PADRAO["microkafka_configurador"]


def obter_nome_container_microkafka_ui(configuracoes):
    return NOMES_CONTAINERS_PADRAO["microkafka_ui"]


def obter_nome_container_mu_whatsapp(configuracoes):
    return NOMES_CONTAINERS_PADRAO["mu_whatsapp"]


def obter_nome_container_proxy_https_linux(configuracoes):
    return NOMES_CONTAINERS_PADRAO["proxy_https_linux"]
